@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Log::Dispatch::File::Stamped; # git description: v0.17-4-g56e90fc
+package Log::Dispatch::File::Stamped; # git description: v0.18-4-g0cbd394
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Logging to date/time stamped files
 # KEYWORDS: log logging output file timestamp date rolling rotate
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use File::Basename        qw(fileparse);
 use File::Spec::Functions qw(catfile);
@@ -47,7 +47,7 @@ sub _basic_init
     $self->{_stamp} = '';
     $self->{_time} = 0;
 
-    # split pathname into path, basename, extension
+    # split pathname into basename, path, extension
     @$self{qw(_name _path _ext)} = fileparse($self->{filename}, '\.[^.]+');
 
     # stored in $self->{filename} (overwrites original); used by _open_file()
@@ -106,7 +106,7 @@ Log::Dispatch::File::Stamped - Logging to date/time stamped files
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -128,7 +128,7 @@ version 0.18
 This module subclasses L<Log::Dispatch::File> for logging to date/time-stamped
 files, respecting all its configuration options. As with other L<Log::Dispatch>
 handlers, the destination file is kept open for as long as the filename remains
-constant (unless C<close_on_write> is set).
+constant (unless C<close_after_write> is set).
 
 =head1 METHODS
 
